<?php

namespace Drupal\domain_language_negotiation\Plugin\LanguageNegotiation;

use Drupal\language\LanguageNegotiationMethodBase;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class for identifying language based on domain language.
 *
 * @LanguageNegotiation(
 *   id = Drupal\domain_language_negotiation\Plugin\LanguageNegotiation\DomainLanguageNegotiation::METHOD_ID,
 *   weight = -1,
 *   name = @Translation("Domain language"),
 *   description = @Translation("Language based on the current domains language settings")
 * )
 */
class DomainLanguageNegotiation extends LanguageNegotiationMethodBase {

  /**
   * Negotiate language based on domain language.
   *
   * Logic:
   * If current language is available for the domain, use that.
   * Otherwise use the domains default language.
   */
  const METHOD_ID = 'domain-language';

  /**
   * {@inheritdoc}
   */
  public function getLangcode(Request $request = NULL) {
    /** @var DomainNegotiatorInterface $negotiator */
    $negotiator = \Drupal::service('domain.negotiator');

    /** @var DomainInterface $domain */
    if ($domain = $negotiator->getActiveDomain()) {
      $name = 'domain.language.' . $domain->getOriginalId() . '.language.negotiation';
      $domain_languages = \Drupal::configFactory()->get($name)->get('languages');
      $current_language = \Drupal::languageManager()->getCurrentLanguage()->getId();

      // If current language is enabled for the domain, use that.
      if (is_array($domain_languages) && in_array($current_language, $domain_languages)) {
          return $current_language;
      }

      // Otherwise use the domains default language.
      $config = \Drupal::config('domain.config.' . $domain->getOriginalId() . '.system.site')->getRawData();
      if (isset($config['default_langcode'])) {
        return $config['default_langcode'];
      }
    }

    return NULL;
  }

}
